==> glib-web-0.4.21.tgz: package/action.js <==
import TypeUtils from "./utils/type"

import ActionsFormsSubmitV1 from "./actions/forms/submit"
import ActionsFormsEncodeV1 from "./actions/forms/encode"

import ActionsHttpPostV1 from "./actions/http/post"
import ActionsHttpPatchV1 from "./actions/http/patch"
import ActionsHttpDeleteV1 from "./actions/http/delete"

import ActionsDialogsAlert from "./actions/dialogs/alert"
// import ActionsDialogsConfirm from "./actions/dialogs/confirm"
import ActionsDialogsOpen from "./actions/dialogs/open"
import ActionsDialogsClose from "./actions/dialogs/close"
import ActionsDialogsOptions from "./actions/dialogs/options"
import ActionsDialogsNotification from "./actions/dialogs/notification"
import ActionsDialogsOauth from "./actions/dialogs/oauth"

import ActionsSnackbarsAlert from "./actions/snackbars/alert"
// import ActionsSnackbarsConfirm from "./actions/snackbars/confirm"
import ActionsSnackbarsOptions from "./actions/snackbars/options"

import ActionsWindowsClose from "./actions/windows/close"
import ActionsWindowsCloseAll from "./actions/windows/closeAll"
import ActionsWindowsOpen from "./actions/windows/open"
import ActionsWindowsOpenWeb from "./actions/windows/openWeb"
import ActionsWindowsReload from "./actions/windows/reload"

import ActionsAuthSaveCsrfToken from "./actions/auth/saveCsrfToken"
import ActionsAuthRestart from "./actions/auth/restart"

const actions = {
  "forms/submit-v1": ActionsFormsSubmitV1,
  "forms/encode-v1": ActionsFormsEncodeV1,

  "http/post-v1": ActionsHttpPostV1,
  "http/patch-v1": ActionsHttpPatchV1,
  "http/delete-v1": ActionsHttpDeleteV1,

  "dialogs/alert-v1": ActionsDialogsAlert,
  // "dialogs/confirm-v1": ActionsDialogsConfirm,
  "dialogs/open-v1": ActionsDialogsOpen,
  "dialogs/close-v1": ActionsDialogsClose,
  "dialogs/options-v1": ActionsDialogsOptions,
  "dialogs/notification-v1": ActionsDialogsNotification,
  "dialogs/oauth-v1": ActionsDialogsOauth,

  "snackbars/alert-v1": ActionsSnackbarsAlert,
  // "snackbars/confirm-v1": ActionsSnackbarsConfirm,
  "snackbars/options-v1": ActionsSnackbarsOptions,

  "windows/close-v1": ActionsWindowsClose,
  "windows/closeAll-v1": ActionsWindowsCloseAll,
  "windows/open-v1": ActionsWindowsOpen,
  "windows/openWeb-v1": ActionsWindowsOpenWeb,
  "windows/reload-v1": ActionsWindowsReload,

  "auth/saveCsrfToken-v1": ActionsAuthSaveCsrfToken,
  "auth/restart-v1": ActionsAuthRestart,
};

export default class Action {
  static execute(spec, target, component, params = {}) {
    if (!TypeUtils.isObject(spec)) {
      return
    }

    const name = spec["action"]
    if (TypeUtils.isString(name)) {
      console.log(`Executing "${name}"`)

      try {
        const action = new actions[name]()
        // action.execute(Object.assign(spec, params), target, component)
        action.execute(spec, target, component, params)
      }
      catch (e) {
        console.log(`Failed executing command: "${e.message}"`)
      }
    }
    else {
      console.log(`Invalid action: "${name}"`)
    }
  }
}

window.Action = Action

==> glib-web-0.4.39.tgz: package/action.js <==
import TypeUtils from "./utils/type"

import ActionsFormsSubmitV1 from "./actions/forms/submit"
import ActionsFormsEncodeV1 from "./actions/forms/encode"

import ActionsHttpPostV1 from "./actions/http/post"
import ActionsHttpPatchV1 from "./actions/http/patch"
import ActionsHttpDeleteV1 from "./actions/http/delete"

import ActionsDialogsAlert from "./actions/dialogs/alert"
// import ActionsDialogsConfirm from "./actions/dialogs/confirm"
import ActionsDialogsShow from "./actions/dialogs/show"
import ActionsDialogsOpen from "./actions/dialogs/open"
import ActionsDialogsClose from "./actions/dialogs/close"
import ActionsDialogsOptions from "./actions/dialogs/options"
import ActionsDialogsNotification from "./actions/dialogs/notification"
import ActionsDialogsOauth from "./actions/dialogs/oauth"

import ActionsSnackbarsAlert from "./actions/snackbars/alert"
// import ActionsSnackbarsConfirm from "./actions/snackbars/confirm"
import ActionsSnackbarsSelect from "./actions/snackbars/select"

import ActionsSheetsSelect from "./actions/sheets/select"

import ActionsWindowsClose from "./actions/windows/close"
import ActionsWindowsCloseAll from "./actions/windows/closeAll"
import ActionsWindowsOpen from "./actions/windows/open"
import ActionsWindowsOpenWeb from "./actions/windows/openWeb"
import ActionsWindowsReload from "./actions/windows/reload"

import ActionsAuthSaveCsrfToken from "./actions/auth/saveCsrfToken"
import ActionsAuthRestart from "./actions/auth/restart"

const actions = {
  "forms/submit-v1": ActionsFormsSubmitV1,
  "forms/encode-v1": ActionsFormsEncodeV1,

  "http/post-v1": ActionsHttpPostV1,
  "http/patch-v1": ActionsHttpPatchV1,
  "http/delete-v1": ActionsHttpDeleteV1,

  "dialogs/alert-v1": ActionsDialogsAlert,
  // "dialogs/confirm-v1": ActionsDialogsConfirm,
  "dialogs/show-v1": ActionsDialogsShow,
  "dialogs/open-v1": ActionsDialogsOpen,
  "dialogs/close-v1": ActionsDialogsClose,
  "dialogs/options-v1": ActionsDialogsOptions,
  "dialogs/notification-v1": ActionsDialogsNotification,
  "dialogs/oauth-v1": ActionsDialogsOauth,

  "snackbars/alert-v1": ActionsSnackbarsAlert,
  // "snackbars/confirm-v1": ActionsSnackbarsConfirm,
  "snackbars/select-v1": ActionsSnackbarsSelect,

  "sheets/select-v1": ActionsSheetsSelect,

  "windows/close-v1": ActionsWindowsClose,
  "windows/closeAll-v1": ActionsWindowsCloseAll,
  "windows/open-v1": ActionsWindowsOpen,
  "windows/openWeb-v1": ActionsWindowsOpenWeb,
  "windows/reload-v1": ActionsWindowsReload,

  "auth/saveCsrfToken-v1": ActionsAuthSaveCsrfToken,
  "auth/restart-v1": ActionsAuthRestart,
};

export default class Action {
  static execute(spec, target, component, params = {}) {
    if (!TypeUtils.isObject(spec)) {
      return
    }

    const name = spec["action"]
    if (TypeUtils.isString(name)) {
      console.log(`Executing "${name}"`)

      try {
        const action = new actions[name]()
        // action.execute(Object.assign(spec, params), target, component)
        action.execute(spec, target, component, params)
      }
      catch (e) {
        console.log(`Failed executing command: "${e.message}"`)
      }
    }
    else {
      console.log(`Invalid action: "${name}"`)
    }
  }
}

window.Action = Action
